@@ -301,7 +301,7 @@ GSC_add_phone (const gchar *label, const struct GNUNET_GNSRECORD_Data *rd)
   if (NULL != phone_label)
     GSC_remove_phone ();
   GNUNET_break (NULL == phone_label);
-  GNUNET_free_non_null (my_rd_data);
+  GNUNET_free (my_rd_data);
   phone_label = GNUNET_strdup (label);
   my_rd = *rd;
   my_rd.expiration_time = expiration_time.rel_value_us;
@@ -342,7 +342,7 @@ static void
 finish_shutdown ()
 {
   GNUNET_SCHEDULER_add_now (&async_disconnect, NULL);
-  GNUNET_free_non_null (my_rd_data);
+  GNUNET_free (my_rd_data);
   memset (&my_rd, 0, sizeof (my_rd));
   GNUNET_CRYPTO_ecdsa_key_clear (&zone_pkey);
 }
