@@ -366,7 +366,7 @@ process_paste (GtkClipboard *cb, const gchar *text, gpointer data)
   kskuri = GNUNET_FS_uri_ksk_create (text, &emsg);
   if (NULL == kskuri)
   {
-    GNUNET_free_non_null (emsg);
+    GNUNET_free (emsg);
     return;
   }
   GNUNET_FS_GTK_handle_uri (kskuri, 1);
@@ -523,7 +523,7 @@ service_list_callback (void *cls,
     return;
   service_list = format_service_list (count, list);
   GNUNET_FS_GTK_update_connection_indicator (cls, TRUE, service_list);
-  GNUNET_free_non_null (service_list);
+  GNUNET_free (service_list);
 }
 
 
@@ -536,7 +536,7 @@ arm_connection_state_change (void *cls, int connected)
   {
     service_list = format_service_list (0, NULL);
     GNUNET_FS_GTK_update_connection_indicator (cls, TRUE, service_list);
-    GNUNET_free_non_null (service_list);
+    GNUNET_free (service_list);
     GNUNET_ARM_request_service_list (arm, &service_list_callback, cls);
   }
   else
