@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -31,7 +31,9 @@
 #include <gnunet/gnunet_gns_service.h>
 #include <gnunet/gnunet_identity_service.h>
 #include <gnunet/gnunet_namestore_service.h>
+#if HAVE_EXTRACTOR_H
 #include <extractor.h>
+#endif
 
 
 /**
@@ -63,13 +65,12 @@ struct SearchLookup
   /**
    * Task to trigger timeout.
    */
-  GNUNET_SCHEDULER_TaskIdentifier timeout_task;
+  struct GNUNET_SCHEDULER_Task *timeout_task;
 
   /**
    * Desired anonymity level.
    */
   guint anonymity_level;
-
 };
 
 
@@ -138,7 +139,6 @@ struct PseuLookupContext
    * Nickname we're saving under.
    */
   char *nick;
-
 };
 
 
@@ -203,7 +203,7 @@ struct GNUNET_GTK_MainWindowContext
   GtkComboBox *download_anonymity_combo;
   GtkCheckButton *download_recursive_checkbutton;
   GtkButton *download_download_button;
-  GtkVBox *download_panel;
+  GtkBox *download_panel;
 
   GtkNotebook *notebook;
 
@@ -254,7 +254,6 @@ struct GNUNET_GTK_MainWindowContext
    * Our zone for SKS operations.  Can be NULL.
    */
   struct GNUNET_CRYPTO_EcdsaPrivateKey *sks_zone;
-
 };
 
 
@@ -262,86 +261,86 @@ struct GNUNET_GTK_MainWindowContext
  * Columns in the search namespace model.
  */
 enum GNUNET_GTK_FS_MAIN_WINDOW_SearchNamespaceModelColumns
-  {
-    /**
+{
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_NAME = 0,
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_NAME = 0,
 
-    /**
+  /**
      * A gpointer.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_KEY = 1,
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_KEY = 1,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_ROOT = 2,
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_ROOT = 2,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_TOOLTIP = 3,
-  };
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_NAMESPACE_MC_TOOLTIP = 3,
+};
 
 
 /**
  * Columns in the meta data model.
  */
 enum GNUNET_GTK_FS_MAIN_WINDOW_MetaDataModelColumns
-  {
-    /**
+{
+  /**
      * A guint.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE = 0,
+  GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE = 0,
 
-    /**
+  /**
      * A guint.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_FORMAT = 1,
+  GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_FORMAT = 1,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE_STRING = 2,
+  GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE_STRING = 2,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_VALUE = 3,
-  };
+  GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_VALUE = 3,
+};
 
 
 /**
  * Columns in the search mime model.
  */
 enum GNUNET_GTK_FS_MAIN_WINDOW_SearchMimeModelColumns
-  {
-    /**
+{
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_MIME = 0,
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_MIME = 0,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_TYPE = 1,
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_TYPE = 1,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_EXTENSION = 2,
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_EXTENSION = 2,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_LOSSYNESS = 3,
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_LOSSYNESS = 3,
 
-    /**
+  /**
      * A gchararray.
      */
-    GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_FREEDOM = 4,
-  };
+  GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_FREEDOM = 4,
+};
 
 /**
  * Get main context.
@@ -402,8 +401,9 @@ GNUNET_FS_GTK_get_main_window_object (const char *name);
  * @return TRUE on success, FALSE on error
  */
 gboolean
-GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
-                                         gchar * combo_name, guint * p_level);
+GNUNET_GTK_get_selected_anonymity_level (GtkBuilder *builder,
+                                         gchar *combo_name,
+                                         guint *p_level);
 
 
 /**
@@ -414,7 +414,8 @@ GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
  * @return TRUE on success, FALSE on error
  */
 gboolean
-GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo, guint *p_level);
+GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo,
+                                               guint *p_level);
 
 
 /**
@@ -427,7 +428,8 @@ GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo, guint *p_leve
  * @return TRUE on success, FALSE on error (no item with such level)
  */
 gboolean
-GNUNET_GTK_select_anonymity_level (GtkBuilder * builder, gchar * combo_name,
+GNUNET_GTK_select_anonymity_level (GtkBuilder *builder,
+                                   gchar *combo_name,
                                    guint sel_level);
 
 
