@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010, 2012 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010, 2012 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -44,7 +44,8 @@
  */
 char *
 GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
-                                    const char *data, size_t data_len)
+                                    const char *data,
+                                    size_t data_len)
 {
   switch (format)
   {
@@ -52,10 +53,12 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
     /* data must not contain NULLs (hence the -1) */
     if (g_utf8_validate (data, data_len - 1, NULL))
       return GNUNET_strdup (data);
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-		_("Failed to validate supposedly utf-8 string `%s' of length %u, assuming it to be a C string\n"),
-		data,
-		(unsigned int) data_len);
+    GNUNET_log (
+      GNUNET_ERROR_TYPE_INFO,
+      _ (
+        "Failed to validate supposedly utf-8 string `%s' of length %u, assuming it to be a C string\n"),
+      data,
+      (unsigned int) data_len);
     format = EXTRACTOR_METAFORMAT_C_STRING;
     /* fall-through */
   case EXTRACTOR_METAFORMAT_C_STRING:
@@ -95,11 +98,13 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
  * @return 0 to continue (always)
  */
 int
-GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls, const char *plugin_name,
+GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls,
+                                           const char *plugin_name,
                                            enum EXTRACTOR_MetaType type,
                                            enum EXTRACTOR_MetaFormat format,
                                            const char *data_mime_type,
-                                           const char *data, size_t data_len)
+                                           const char *data,
+                                           size_t data_len)
 {
   GtkListStore *ls = GTK_LIST_STORE (cls);
   char *data_to_insert;
@@ -107,16 +112,21 @@ GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls, const char *plugin_name,
   data_to_insert = GNUNET_FS_GTK_dubious_meta_to_utf8 (format, data, data_len);
   if (NULL == data_to_insert)
     return 0;
-  gtk_list_store_insert_with_values (ls, NULL, G_MAXINT,
-                                     GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE,
-                                     type,
-                                     GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_FORMAT,
-                                     format,
-                                     GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE_STRING,
-                                     EXTRACTOR_metatype_to_string (type),
-                                     GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_VALUE,
-                                     data_to_insert,
-                                     -1);
+  gtk_list_store_insert_with_values (
+    ls,
+    NULL,
+    G_MAXINT,
+    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE,
+    type,
+    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_FORMAT,
+    format,
+#if HAVE_EXTRACTOR
+    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE_STRING,
+    EXTRACTOR_metatype_to_string (type),
+#endif
+    GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_VALUE,
+    data_to_insert,
+    -1);
   GNUNET_free (data_to_insert);
   return 0;
 }
@@ -129,8 +139,8 @@ GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls, const char *plugin_name,
  * @return NULL on error, otherwise the embedded thumbnail
  */
 GdkPixbuf *
-GNUNET_FS_GTK_get_thumbnail_from_meta_data (const struct
-                                            GNUNET_CONTAINER_MetaData *meta)
+GNUNET_FS_GTK_get_thumbnail_from_meta_data (
+  const struct GNUNET_CONTAINER_MetaData *meta)
 {
   GdkPixbuf *pixbuf;
   GdkPixbufLoader *loader;
@@ -173,7 +183,8 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
   void *ddata;
   int ret;
 
-  if (GNUNET_OK != GNUNET_DISK_file_size (filename, &fsize, GNUNET_YES, GNUNET_YES))
+  if (GNUNET_OK !=
+      GNUNET_DISK_file_size (filename, &fsize, GNUNET_YES, GNUNET_YES))
   {
     GNUNET_break (0);
     return GNUNET_SYSERR;
@@ -183,24 +194,31 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
     /* empty file, cannot be a directory */
     return GNUNET_SYSERR;
   }
-  if (NULL == (fh = GNUNET_DISK_file_open (filename, GNUNET_DISK_OPEN_READ,
-					   GNUNET_DISK_PERM_NONE)))
+  if (NULL == (fh = GNUNET_DISK_file_open (filename,
+                                           GNUNET_DISK_OPEN_READ,
+                                           GNUNET_DISK_PERM_NONE)))
   {
     GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_ERROR, "open", filename);
     return GNUNET_SYSERR;
   }
-  if (NULL == (ddata = GNUNET_DISK_file_map (fh, &mh, GNUNET_DISK_MAP_TYPE_READ, (size_t) fsize)))
+  if (NULL == (ddata = GNUNET_DISK_file_map (fh,
+                                             &mh,
+                                             GNUNET_DISK_MAP_TYPE_READ,
+                                             (size_t) fsize)))
   {
     GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_ERROR, "mmap", filename);
     GNUNET_break (GNUNET_OK == GNUNET_DISK_file_close (fh));
     return GNUNET_SYSERR;
   }
-  if (GNUNET_SYSERR ==
-      GNUNET_FS_directory_list_contents ((size_t) fsize, ddata, 0, dep,
-                                         dep_cls))
+  if (GNUNET_SYSERR == GNUNET_FS_directory_list_contents ((size_t) fsize,
+                                                          ddata,
+                                                          0,
+                                                          dep,
+                                                          dep_cls))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Selected file `%s' is not a GNUnet directory!\n"), filename);
+                _ ("Selected file `%s' is not a GNUnet directory!\n"),
+                filename);
     ret = GNUNET_SYSERR;
   }
   else
@@ -223,39 +241,39 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
  * @return description of the result in utf-8, never NULL
  */
 char *
-GNUNET_FS_GTK_get_description_from_metadata (const struct GNUNET_CONTAINER_MetaData *meta,
-					     int *is_a_dup)
+GNUNET_FS_GTK_get_description_from_metadata (
+  const struct GNUNET_CONTAINER_MetaData *meta,
+  int *is_a_dup)
 {
   char *desc;
   char *utf8_desc;
 
-  desc =
-      GNUNET_CONTAINER_meta_data_get_first_by_types (meta,
-                                                     EXTRACTOR_METATYPE_PACKAGE_NAME,
-                                                     EXTRACTOR_METATYPE_TITLE,
-                                                     EXTRACTOR_METATYPE_BOOK_TITLE,
-                                                     EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME,
-                                                     EXTRACTOR_METATYPE_FILENAME,
-                                                     EXTRACTOR_METATYPE_DESCRIPTION,
-                                                     EXTRACTOR_METATYPE_SUMMARY,
-                                                     EXTRACTOR_METATYPE_ALBUM,
-                                                     EXTRACTOR_METATYPE_COMMENT,
-                                                     EXTRACTOR_METATYPE_SUBJECT,
-                                                     EXTRACTOR_METATYPE_KEYWORDS,
-                                                     -1);
+  desc = GNUNET_CONTAINER_meta_data_get_first_by_types (
+    meta,
+    EXTRACTOR_METATYPE_PACKAGE_NAME,
+    EXTRACTOR_METATYPE_TITLE,
+    EXTRACTOR_METATYPE_BOOK_TITLE,
+    EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME,
+    EXTRACTOR_METATYPE_FILENAME,
+    EXTRACTOR_METATYPE_DESCRIPTION,
+    EXTRACTOR_METATYPE_ALBUM,
+    EXTRACTOR_METATYPE_COMMENT,
+    EXTRACTOR_METATYPE_SUBJECT,
+    EXTRACTOR_METATYPE_KEYWORDS,
+    -1);
   if (desc == NULL)
   {
     *is_a_dup = GNUNET_YES;
-    return GNUNET_strdup (_("no description supplied"));
+    return GNUNET_strdup (_ ("no description supplied"));
   }
-  utf8_desc =
-    GNUNET_FS_GTK_dubious_meta_to_utf8 (EXTRACTOR_METAFORMAT_UTF8, desc,
-					strlen (desc) + 1);
+  utf8_desc = GNUNET_FS_GTK_dubious_meta_to_utf8 (EXTRACTOR_METAFORMAT_UTF8,
+                                                  desc,
+                                                  strlen (desc) + 1);
   GNUNET_free (desc);
   if (utf8_desc == NULL)
   {
     *is_a_dup = GNUNET_YES;
-    return GNUNET_strdup (_("no description supplied"));
+    return GNUNET_strdup (_ ("no description supplied"));
   }
   *is_a_dup = GNUNET_NO;
   return utf8_desc;
@@ -271,7 +289,7 @@ GNUNET_FS_GTK_get_description_from_metadata (const struct GNUNET_CONTAINER_MetaD
  */
 void
 GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
-			  guint anonymity_level)
+                          guint anonymity_level)
 {
   GtkEntry *query_entry;
   GtkComboBox *ns_cb;
@@ -289,14 +307,15 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
     GNUNET_FS_GTK_open_download_as_dialog (de);
     return;
   }
-  query_entry = GTK_ENTRY (GNUNET_FS_GTK_get_main_window_object ("main_window_search_entry"));
-  ns_cb = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object ("main_window_search_namespace_combobox"));
+  query_entry = GTK_ENTRY (
+    GNUNET_FS_GTK_get_main_window_object ("main_window_search_entry"));
+  ns_cb = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
+    "main_window_search_namespace_combobox"));
   ns_entry = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (ns_cb)));
   if (GNUNET_FS_uri_test_sks (uri))
   {
     /* select the namespace */
-    if (GNUNET_OK !=
-	GNUNET_FS_uri_sks_get_namespace (uri, &want))
+    if (GNUNET_OK != GNUNET_FS_uri_sks_get_namespace (uri, &want))
     {
       GNUNET_break (0);
       return;
@@ -305,16 +324,14 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
       const char *ns_zkey;
 
       ns_zkey = GNUNET_GNSRECORD_pkey_to_zkey (&want);
-      gtk_entry_set_text (ns_entry,
-			  ns_zkey);
+      gtk_entry_set_text (ns_entry, ns_zkey);
     }
     /* set search entry to the namespace identifier */
     {
       char *query_string;
 
       query_string = GNUNET_FS_uri_sks_get_content_id (uri);
-      gtk_entry_set_text (query_entry,
-			  query_string);
+      gtk_entry_set_text (query_entry, query_string);
       GNUNET_free (query_string);
     }
     return;
@@ -328,8 +345,7 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
       char *query_string;
 
       query_string = GNUNET_FS_uri_ksk_to_string_fancy (uri);
-      gtk_entry_set_text (query_entry,
-			  query_string);
+      gtk_entry_set_text (query_entry, query_string);
       GNUNET_free (query_string);
     }
     return;
@@ -346,8 +362,7 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
  * @return #GNUNET_OK if iter was filled, #GNUNET_SYSERR otherwise
  */
 int
-GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr,
-				    GtkTreeIter *iter)
+GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr, GtkTreeIter *iter)
 {
   int result = GNUNET_SYSERR;
   if (rr != NULL)
@@ -360,8 +375,7 @@ GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr,
       model = gtk_tree_row_reference_get_model (rr);
       if (path != NULL && model != NULL)
       {
-        if (gtk_tree_model_get_iter (model,
-            iter, path))
+        if (gtk_tree_model_get_iter (model, iter, path))
           result = GNUNET_OK;
         gtk_tree_path_free (path);
       }
@@ -414,9 +428,9 @@ GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model, GtkTreeIter *iter)
  */
 gboolean
 GNUNET_GTK_tree_model_get_next_flat_iter (GtkTreeModel *model,
-					  GtkTreeIter *iter,
-					  gboolean allow_children,
-					  GtkTreeIter *next_iter)
+                                          GtkTreeIter *iter,
+                                          gboolean allow_children,
+                                          GtkTreeIter *next_iter)
 {
   GtkTreeIter current_iter = *iter;
   while (TRUE)
@@ -438,7 +452,7 @@ GNUNET_GTK_tree_model_get_next_flat_iter (GtkTreeModel *model,
       }
     }
     allow_children = FALSE;
-    if (!gtk_tree_model_iter_parent (model, &tmp_iter, &current_iter))
+    if (! gtk_tree_model_iter_parent (model, &tmp_iter, &current_iter))
       return FALSE;
     current_iter = tmp_iter;
   }
