@@ -29,7 +29,6 @@
 #include <string.h>
 
 
-
 /**
  * Helper function of GNUNET_GTK_FS_metadata_copy_selection_activated
  * which copies the (selected) entries from the tree view to the
@@ -41,14 +40,17 @@
  * @param user_data 'GList**' where we should store the types and values found
  */
 static void
-copy_metadata_to_clipboard (GtkTreeModel * model, GtkTreePath * path,
-                            GtkTreeIter * iter, gpointer user_data)
+copy_metadata_to_clipboard (GtkTreeModel *model,
+                            GtkTreePath *path,
+                            GtkTreeIter *iter,
+                            gpointer user_data)
 {
   GList **l = user_data;
   gchar *type;
   gchar *value;
 
-  gtk_tree_model_get (model, iter,
+  gtk_tree_model_get (model,
+                      iter,
                       GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_TYPE_STRING,
                       &type,
                       GNUNET_GTK_FS_MAIN_WINDOW_META_DATA_MC_META_VALUE,
@@ -66,8 +68,8 @@ copy_metadata_to_clipboard (GtkTreeModel * model, GtkTreePath * path,
  * @param user_data the GtkBuilder of the main window
  */
 void
-GNUNET_GTK_FS_metadata_copy_selection_activated (GtkMenuItem * menuitem,
-						 gpointer user_data)
+GNUNET_GTK_FS_metadata_copy_selection_activated (GtkMenuItem *menuitem,
+                                                 gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
   GtkTreeView *tree;
@@ -83,7 +85,8 @@ GNUNET_GTK_FS_metadata_copy_selection_activated (GtkMenuItem * menuitem,
   tree = main_ctx->md_treeview;
   pairs = NULL;
   gtk_tree_selection_selected_foreach (gtk_tree_view_get_selection (tree),
-                                       &copy_metadata_to_clipboard, &pairs);
+                                       &copy_metadata_to_clipboard,
+                                       &pairs);
   if (NULL == pairs)
     return; /* nothing selected */
   total_len = 0;
@@ -93,12 +96,12 @@ GNUNET_GTK_FS_metadata_copy_selection_activated (GtkMenuItem * menuitem,
     type = pos;
     value = pos->next;
     GNUNET_assert (NULL != value);
-    total_len +=
-      strlen ((gchar *) type->data) + strlen ((gchar *) value->data) +
-      2 /* ": " */  + ((NULL != value->next) ? 1 : 0) /* "\n" */ ;
+    total_len += strlen ((gchar *) type->data) +
+                 strlen ((gchar *) value->data) + 2 /* ": " */ +
+                 ((NULL != value->next) ? 1 : 0) /* "\n" */;
   }
   GNUNET_assert (total_len > 0);
-  total_len++;             /* "\0" */
+  total_len++; /* "\0" */
   s = g_new0 (gchar, total_len);
   if (NULL == s)
   {
@@ -135,24 +138,23 @@ GNUNET_GTK_FS_metadata_copy_selection_activated (GtkMenuItem * menuitem,
  * @param user_data the gtk builder of the main window
  */
 gboolean
-GNUNET_GTK_main_window_metadata_treeview_button_press_event_cb (GtkWidget * widget,
-                                                                GdkEvent * event,
-                                                                gpointer user_data)
+GNUNET_GTK_main_window_metadata_treeview_button_press_event_cb (
+  GtkWidget *widget,
+  GdkEvent *event,
+  gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
   GdkEventButton *event_button = (GdkEventButton *) event;
   GtkMenu *menu;
 
   /* Ignore double-clicks and triple-clicks */
-  if ( (event_button->button != 3) ||
-       (event_button->type != GDK_BUTTON_PRESS) )
+  if ((event_button->button != 3) || (event_button->type != GDK_BUTTON_PRESS))
     return FALSE;
-  menu = GTK_MENU (gtk_builder_get_object (main_ctx->builder,
-                                           "metadata_popup_menu"));
+  menu = GTK_MENU (
+    gtk_builder_get_object (main_ctx->builder, "metadata_popup_menu"));
   if (NULL == menu)
     return FALSE;
-  gtk_menu_popup_at_pointer (menu,
-                             event);
+  gtk_menu_popup_at_pointer (menu, event);
   return FALSE;
 }
 
@@ -166,13 +168,14 @@ GNUNET_GTK_main_window_metadata_treeview_button_press_event_cb (GtkWidget * widg
  * @return TRUE we did it
  */
 gboolean
-GNUNET_GTK_main_window_metadata_treeview_popup_menu_cb (GtkWidget * widget,
+GNUNET_GTK_main_window_metadata_treeview_popup_menu_cb (GtkWidget *widget,
                                                         gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
   GtkMenu *menu;
 
-  menu = GTK_MENU (gtk_builder_get_object (main_ctx->builder, "metadata_popup_menu"));
+  menu = GTK_MENU (
+    gtk_builder_get_object (main_ctx->builder, "metadata_popup_menu"));
   if (NULL == menu)
     return FALSE;
   gtk_menu_popup_at_widget (menu,
