@@ -256,7 +256,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
                 keywords,
                 emsg);
     g_free (keywords);
-    GNUNET_free_non_null (emsg);
+    GNUNET_free (emsg);
     return;
   }
   g_free (keywords);
@@ -342,7 +342,7 @@ end_pseu_lookup (void *cls)
     GNUNET_NAMESTORE_disconnect (lctx->namestore);
     lctx->namestore = NULL;
   }
-  GNUNET_free_non_null (lctx->nick);
+  GNUNET_free (lctx->nick);
   GNUNET_free (lctx);
 }
 
