@@ -2009,7 +2009,7 @@ update_treeview_after_edit (void *cls,
                       PUBLISH_MC_REPLICATION_LEVEL,
                       (guint) bo->replication_level,
                       -1);
-  GNUNET_free_non_null (name);
+  GNUNET_free (name);
   return GNUNET_SYSERR;
 }
 
@@ -2161,7 +2161,7 @@ close_master_publish_dialog (struct MainPublishingDialogContext *ctx)
   GNUNET_IDENTITY_disconnect (ctx->identity);
   gtk_widget_destroy (GTK_WIDGET (ctx->master_pubdialog));
   g_object_unref (G_OBJECT (ctx->builder));
-  GNUNET_free_non_null (ctx->ns_name);
+  GNUNET_free (ctx->ns_name);
   g_free (ctx->previous_id);
   GNUNET_free (ctx);
   return GNUNET_YES;
@@ -2609,7 +2609,7 @@ add_updateable_to_ts (void *cls,
   GNUNET_CRYPTO_hash (hashbuf, hashbufsize, &hc);
 
   GNUNET_free (uristring);
-  GNUNET_free_non_null (mdbuf);
+  GNUNET_free (mdbuf);
   GNUNET_free (hashbuf);
 
   spath = NULL;
@@ -2733,7 +2733,7 @@ add_updateable_to_ts (void *cls,
 
 /**
  * Called by a hashmap iterator.
- * Frees its argument with GNUNET_free_non_null().
+ * Frees its argument with GNUNET_free().
  *
  * @param cls closure
  * @param key key from the map
@@ -2743,7 +2743,7 @@ add_updateable_to_ts (void *cls,
 static int
 free_seen_paths (void *cls, const struct GNUNET_HashCode *key, void *value)
 {
-  GNUNET_free_non_null (value);
+  GNUNET_free (value);
   return GNUNET_YES;
 }
 
