@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2011, 2013 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2011, 2013 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -36,7 +36,6 @@
 #include <gnunet/platform.h>
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_fs_service.h>
-#include <extractor.h>
 #include <gtk/gtk.h>
 #include <gladeui/glade.h>
 #include <gdk/gdkkeysyms.h>
@@ -53,7 +52,6 @@
 struct GNUNET_GTK_MainLoop;
 
 
-
 /* ****************** Initialization *************** */
 
 /**
@@ -64,8 +62,7 @@ struct GNUNET_GTK_MainLoop;
  * @return new main window to initialize
  */
 GtkWidget *
-GNUNET_GTK_plug_me (const char *env_name,
-                    GtkWidget *main_window);
+GNUNET_GTK_plug_me (const char *env_name, GtkWidget *main_window);
 
 
 /**
@@ -131,7 +128,8 @@ GNUNET_GTK_get_new_builder2 (const char *filename,
  *        use "NULL" to pass the GtkBuilder itself.
  * @return NULL on error
  */
-#define GNUNET_GTK_get_new_builder(filename,user_data) GNUNET_GTK_get_new_builder2(filename,user_data,NULL)
+#define GNUNET_GTK_get_new_builder(filename, user_data) \
+  GNUNET_GTK_get_new_builder2 (filename, user_data, NULL)
 
 
 /**
@@ -157,29 +155,9 @@ GNUNET_GTK_display_about (const char *dialogfile);
  */
 gboolean
 GNUNET_GTK_get_tree_string (GtkTreeView *treeview,
-			    GtkTreePath *treepath,
-                            guint column, gchar ** value);
-
-
-/**
- * Create our tray icon.
- *
- * @param ml main loop
- * @param main handle to the main window (show or hide)
- * @param icon_name name of the tray icon file
- * @param tooltip tooltip for the tray icon
- */
-void
-GNUNET_GTK_tray_icon_create (struct GNUNET_GTK_MainLoop *ml,
-			     GtkWindow * main, const char *icon_name,
-                             const char *tooltip);
-
-
-/**
- * Destroy the tray icon.
- */
-void
-GNUNET_GTK_tray_icon_destroy (void);
+                            GtkTreePath *treepath,
+                            guint column,
+                            gchar **value);
 
 
 /**
@@ -189,7 +167,7 @@ GNUNET_GTK_tray_icon_destroy (void);
  * @return string in UTF-8, NULL if str_loc was NULL
  */
 char *
-GNUNET_GTK_from_loc_to_utf8 (const char * str_loc);
+GNUNET_GTK_from_loc_to_utf8 (const char *str_loc);
 
 
 /**
@@ -199,7 +177,7 @@ GNUNET_GTK_from_loc_to_utf8 (const char * str_loc);
  * @return selected filename as UTF-8, NULL on errors
  */
 char *
-GNUNET_GTK_filechooser_get_filename_utf8 (GtkFileChooser * fc);
+GNUNET_GTK_filechooser_get_filename_utf8 (GtkFileChooser *fc);
 
 
 /**
@@ -209,8 +187,7 @@ GNUNET_GTK_filechooser_get_filename_utf8 (GtkFileChooser * fc);
  * @param root root of the subtree to remove
  */
 void
-GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore * ts,
-					GtkTreeIter * root);
+GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore *ts, GtkTreeIter *root);
 
 
 /* ******************* main loop ***************** */
@@ -225,15 +202,17 @@ GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore * ts,
  * @param argv command line options
  * @param options allowed command line options
  * @param main_window_file glade file for the main window
- * @param main_task first task to run, closure will be set to the 'struct GNUNET_GTK_MainLoop'
+ * @param main_task first task to run, closure will be set to the `struct GNUNET_GTK_MainLoop`
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error (i.e. bad command-line options, etc)
  */
 int
-GNUNET_GTK_main_loop_start (const char *binary_name, const char *binary_help,
-                            int argc, char *const *argv,
+GNUNET_GTK_main_loop_start (const char *binary_name,
+                            const char *binary_help,
+                            int argc,
+                            char *const *argv,
                             struct GNUNET_GETOPT_CommandLineOption *options,
                             const char *main_window_file,
-                            GNUNET_SCHEDULER_Task main_task);
+                            GNUNET_SCHEDULER_TaskCallback main_task);
 
 
 /**
@@ -247,6 +226,7 @@ GObject *
 GNUNET_GTK_main_loop_get_object (struct GNUNET_GTK_MainLoop *ml,
                                  const char *name);
 
+
 /**
  * Get the builder from the main window.
  *
@@ -257,7 +237,6 @@ GtkBuilder *
 GNUNET_GTK_main_loop_get_builder (struct GNUNET_GTK_MainLoop *ml);
 
 
-
 /**
  * Get remaining command line arguments.
  *
@@ -266,9 +245,9 @@ GNUNET_GTK_main_loop_get_builder (struct GNUNET_GTK_MainLoop *ml);
  * @param argv set to argument vector
  */
 void
-GNUNET_GTK_main_loop_get_args (struct GNUNET_GTK_MainLoop * ml,
-			       int *argc,
-			       char *const**argv);
+GNUNET_GTK_main_loop_get_args (struct GNUNET_GTK_MainLoop *ml,
+                               int *argc,
+                               char *const **argv);
 
 
 /**
@@ -319,7 +298,7 @@ GNUNET_GTK_main_loop_quit (struct GNUNET_GTK_MainLoop *ml);
  * Handle for an animation.  Each animation file should only
  * be loaded once and can then be used in multiple tree views.
  */
-struct GNUNET_FS_AnimationContext;
+struct GNUNET_GTK_AnimationContext;
 
 
 /**
@@ -328,7 +307,7 @@ struct GNUNET_FS_AnimationContext;
  * must be told about the tree view and column for the animations
  * to work.
  */
-struct GNUNET_FS_AnimationTreeViewHandle;
+struct GNUNET_GTK_AnimationTreeViewHandle;
 
 
 /**
@@ -339,7 +318,7 @@ struct GNUNET_FS_AnimationTreeViewHandle;
  * @param filename name of the file with the animation to show
  * @return context to use to get the animated pixbuf, NULL on error
  */
-struct GNUNET_FS_AnimationContext *
+struct GNUNET_GTK_AnimationContext *
 GNUNET_GTK_animation_context_create (const char *filename);
 
 
@@ -350,7 +329,7 @@ GNUNET_GTK_animation_context_create (const char *filename);
  * @param ac animation context to destroy.
  */
 void
-GNUNET_GTK_animation_context_destroy (struct GNUNET_FS_AnimationContext *ac);
+GNUNET_GTK_animation_context_destroy (struct GNUNET_GTK_AnimationContext *ac);
 
 
 /**
@@ -363,7 +342,8 @@ GNUNET_GTK_animation_context_destroy (struct GNUNET_FS_AnimationContext *ac);
  * @return pixbuf of the AC, NULL on error loading the pixbuf
  */
 GdkPixbuf *
-GNUNET_GTK_animation_context_get_pixbuf (struct GNUNET_FS_AnimationContext *ac);
+GNUNET_GTK_animation_context_get_pixbuf (
+  struct GNUNET_GTK_AnimationContext *ac);
 
 
 /**
@@ -375,9 +355,9 @@ GNUNET_GTK_animation_context_get_pixbuf (struct GNUNET_FS_AnimationContext *ac);
  * @param image_col column in the tree view with the animated pixbufs
  * @return handle to unregister the tree view later
  */
-struct GNUNET_FS_AnimationTreeViewHandle *
+struct GNUNET_GTK_AnimationTreeViewHandle *
 GNUNET_GTK_animation_tree_view_register (GtkTreeView *tv,
-					 GtkTreeViewColumn *image_col);
+                                         GtkTreeViewColumn *image_col);
 
 
 /**
@@ -386,7 +366,8 @@ GNUNET_GTK_animation_tree_view_register (GtkTreeView *tv,
  * @param atv tree view to unregister
  */
 void
-GNUNET_GTK_animation_tree_view_unregister (struct GNUNET_FS_AnimationTreeViewHandle *atv);
+GNUNET_GTK_animation_tree_view_unregister (
+  struct GNUNET_GTK_AnimationTreeViewHandle *atv);
 
 
 /* ********************* generic helpers ******************* */
@@ -396,22 +377,22 @@ GNUNET_GTK_animation_tree_view_unregister (struct GNUNET_FS_AnimationTreeViewHan
  * Columns in the anonymity level model.
  */
 enum GNUNET_GTK_FS_MAIN_WINDOW_AnonymityLevelModelColumns
-  {
-    /**
-     * A gchararray.
-     */
-    GNUNET_GTK_ANONYMITY_LEVEL_MC_NAME = 0,
+{
+  /**
+   * A gchararray.
+   */
+  GNUNET_GTK_ANONYMITY_LEVEL_MC_NAME = 0,
 
-    /**
-     * A guint.
-     */
-    GNUNET_GTK_ANONYMITY_LEVEL_MC_LEVEL = 1,
+  /**
+   * A guint.
+   */
+  GNUNET_GTK_ANONYMITY_LEVEL_MC_LEVEL = 1,
 
-    /**
-     * A gchararray.
-     */
-    GNUNET_GTK_ANONYMITY_LEVEL_MC_COLOR = 2
-  };
+  /**
+   * A gchararray.
+   */
+  GNUNET_GTK_ANONYMITY_LEVEL_MC_COLOR = 2
+};
 
 
 /**
@@ -422,7 +403,7 @@ enum GNUNET_GTK_FS_MAIN_WINDOW_AnonymityLevelModelColumns
  * @return time converted from the spin button
  */
 struct GNUNET_TIME_Absolute
-GNUNET_GTK_get_expiration_time (GtkSpinButton * spin);
+GNUNET_GTK_get_expiration_time (GtkSpinButton *spin);
 
 
 /**
@@ -435,7 +416,7 @@ GNUNET_GTK_get_expiration_time (GtkSpinButton * spin);
  * the adjustment
  */
 void
-GNUNET_GTK_setup_expiration_year_adjustment (GtkBuilder * builder);
+GNUNET_GTK_setup_expiration_year_adjustment (GtkBuilder *builder);
 
 
 /**
@@ -447,8 +428,9 @@ GNUNET_GTK_setup_expiration_year_adjustment (GtkBuilder * builder);
  * @return TRUE on success, FALSE on failure
  */
 gboolean
-GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
-                                         gchar * combo_name, guint * p_level);
+GNUNET_GTK_get_selected_anonymity_level (GtkBuilder *builder,
+                                         gchar *combo_name,
+                                         guint *p_level);
 
 
 /**
@@ -459,7 +441,8 @@ GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
  * @return TRUE on success, FALSE on failure
  */
 gboolean
-GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo, guint *p_level);
+GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo,
+                                               guint *p_level);
 
 
 #endif
