@@ -54,31 +54,28 @@ GNS_edit_dialog_phone_peer_entry_changed_cb (GtkEditable *entry,
  * @param builder the edit dialog's builder
  */
 static void
-phone_load (void *cls,
-            gchar *n_value,
-            GtkBuilder *builder)
+phone_load (void *cls, gchar *n_value, GtkBuilder *builder)
 {
   const char *minus;
   unsigned int line;
 
-  if (1 != (sscanf (n_value,
-                    "%u-",
-                    &line)))
+  if (1 != (sscanf (n_value, "%u-", &line)))
   {
     GNUNET_break (0);
     return;
   }
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON
-                             (gtk_builder_get_object (builder,
-                                                      "edit_dialog_phone_line_spinbutton")),
-                             line);
+  gtk_spin_button_set_value (
+    GTK_SPIN_BUTTON (
+      gtk_builder_get_object (builder, "edit_dialog_phone_line_spinbutton")),
+    line);
   if (NULL == (minus = strchr (n_value, '-')))
   {
     GNUNET_break (0);
     return;
   }
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_phone_peer_entry")),
+  gtk_entry_set_text (GTK_ENTRY (
+                        gtk_builder_get_object (builder,
+                                                "edit_dialog_phone_peer_entry")),
                       minus + 1);
 }
 
@@ -92,8 +89,7 @@ phone_load (void *cls,
  * @return record value as a string, as specified in the dialog
  */
 static gchar *
-phone_store (void *cls,
-             GtkBuilder *builder)
+phone_store (void *cls, GtkBuilder *builder)
 {
   GtkEntry *entry;
   GtkSpinButton *spin;
@@ -101,16 +97,13 @@ phone_store (void *cls,
   unsigned int line;
   char *ret;
 
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_phone_peer_entry"));
+  entry = GTK_ENTRY (
+    gtk_builder_get_object (builder, "edit_dialog_phone_peer_entry"));
   value = gtk_entry_get_text (entry);
-  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                                  "edit_dialog_phone_line_spinbutton"));
+  spin = GTK_SPIN_BUTTON (
+    gtk_builder_get_object (builder, "edit_dialog_phone_line_spinbutton"));
   line = gtk_spin_button_get_value (spin);
-  GNUNET_asprintf (&ret,
-                   "%u-%s",
-                   line,
-                   value);
+  GNUNET_asprintf (&ret, "%u-%s", line, value);
   return ret;
 }
 
@@ -127,21 +120,20 @@ phone_store (void *cls,
  * @return #GNUNET_OK if there is a valid record value in the dialog
  */
 static int
-phone_validate (void *cls,
-            GtkBuilder *builder)
+phone_validate (void *cls, GtkBuilder *builder)
 {
   GtkEditable *entry;
   const gchar *preedit;
   struct GNUNET_CRYPTO_EcdsaPublicKey pub;
 
-  entry = GTK_EDITABLE (gtk_builder_get_object (builder,
-						"edit_dialog_phone_peer_entry"));
+  entry = GTK_EDITABLE (
+    gtk_builder_get_object (builder, "edit_dialog_phone_peer_entry"));
   preedit = gtk_editable_get_chars (entry, 0, -1);
-  if ( (NULL == preedit) ||
-       (GNUNET_OK !=
-	GNUNET_CRYPTO_ecdsa_public_key_from_string (preedit,
-                                                       strlen (preedit),
-                                                       &pub)) )
+  if ((NULL == preedit) ||
+      (GNUNET_OK !=
+       GNUNET_CRYPTO_ecdsa_public_key_from_string (preedit,
+                                                   strlen (preedit),
+                                                   &pub)))
     return GNUNET_SYSERR;
   return GNUNET_OK;
 }
@@ -158,11 +150,10 @@ libgnunet_plugin_gtk_namestore_phone_init (void *cls)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
-  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] = {
-    { "GNS_edit_dialog_phone_peer_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_phone_peer_entry_changed_cb) },
-    { NULL, NULL }
-  };
+  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
+    {{"GNS_edit_dialog_phone_peer_entry_changed_cb",
+      G_CALLBACK (GNS_edit_dialog_phone_peer_entry_changed_cb)},
+     {NULL, NULL}};
 
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
   plugin->cls = env;
