@@ -35,8 +35,7 @@
  * @param user_data the plugin environment
  */
 static void
-GNS_edit_dialog_pkey_entry_changed_cb (GtkEditable *entry,
-				       gpointer user_data)
+GNS_edit_dialog_pkey_entry_changed_cb (GtkEditable *entry, gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -54,12 +53,11 @@ GNS_edit_dialog_pkey_entry_changed_cb (GtkEditable *entry,
  * @param builder the edit dialog's builder
  */
 static void
-pkey_load (void *cls,
-        gchar *n_value,
-        GtkBuilder *builder)
+pkey_load (void *cls, gchar *n_value, GtkBuilder *builder)
 {
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_pkey_entry")),
+  gtk_entry_set_text (GTK_ENTRY (
+                        gtk_builder_get_object (builder,
+                                                "edit_dialog_pkey_entry")),
                       n_value);
 }
 
@@ -73,14 +71,13 @@ pkey_load (void *cls,
  * @return record value as a string, as specified in the dialog
  */
 static gchar *
-pkey_store (void *cls,
-         GtkBuilder *builder)
+pkey_store (void *cls, GtkBuilder *builder)
 {
   GtkEntry *entry;
   const gchar *value;
 
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_pkey_entry"));
+  entry =
+    GTK_ENTRY (gtk_builder_get_object (builder, "edit_dialog_pkey_entry"));
   value = gtk_entry_get_text (entry);
   return g_strdup (value);
 }
@@ -98,21 +95,20 @@ pkey_store (void *cls,
  * @return #GNUNET_OK if there is a valid record value in the dialog
  */
 static int
-pkey_validate (void *cls,
-            GtkBuilder *builder)
+pkey_validate (void *cls, GtkBuilder *builder)
 {
   GtkEditable *entry;
   const gchar *preedit;
   struct GNUNET_CRYPTO_EcdsaPublicKey pub;
 
-  entry = GTK_EDITABLE (gtk_builder_get_object (builder,
-						"edit_dialog_pkey_entry")),
+  entry =
+    GTK_EDITABLE (gtk_builder_get_object (builder, "edit_dialog_pkey_entry")),
   preedit = gtk_editable_get_chars (entry, 0, -1);
-  if ( (NULL == preedit) ||
-       (GNUNET_OK !=
-	GNUNET_CRYPTO_ecdsa_public_key_from_string (preedit,
-						  strlen (preedit),
-						  &pub)) )
+  if ((NULL == preedit) ||
+      (GNUNET_OK !=
+       GNUNET_CRYPTO_ecdsa_public_key_from_string (preedit,
+                                                   strlen (preedit),
+                                                   &pub)))
     return GNUNET_SYSERR;
   return GNUNET_OK;
 }
@@ -129,11 +125,10 @@ libgnunet_plugin_gtk_namestore_pkey_init (void *cls)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
-  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] = {
-    { "GNS_edit_dialog_pkey_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_pkey_entry_changed_cb) },
-    { NULL, NULL }
-  };
+  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
+    {{"GNS_edit_dialog_pkey_entry_changed_cb",
+      G_CALLBACK (GNS_edit_dialog_pkey_entry_changed_cb)},
+     {NULL, NULL}};
 
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
   plugin->cls = env;
