@@ -1,6 +1,6 @@
 /*
   * This file is part of GNUnet
-  * (C) 2009-2013 Christian Grothoff (and other contributing authors)
+  * Copyright (C) 2009-2013 GNUnet e.V.
   *
   * GNUnet is free software; you can redistribute it and/or modify
   * it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
   *
   * You should have received a copy of the GNU General Public License
   * along with GNUnet; see the file COPYING.  If not, write to the
-  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  * Boston, MA 02111-1307, USA.
+  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  * Boston, MA 02110-1301, USA.
   */
 
 /**
@@ -35,8 +35,7 @@
  * @param user_data the plugin environment
  */
 static void
-GNS_edit_dialog_ptr_entry_changed_cb (GtkEditable *entry,
-				       gpointer user_data)
+GNS_edit_dialog_ptr_entry_changed_cb (GtkEditable *entry, gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -54,12 +53,11 @@ GNS_edit_dialog_ptr_entry_changed_cb (GtkEditable *entry,
  * @param builder the edit dialog's builder
  */
 static void
-ptr_load (void *cls,
-        gchar *n_value,
-        GtkBuilder *builder)
+ptr_load (void *cls, gchar *n_value, GtkBuilder *builder)
 {
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_ptr_entry")),
+  gtk_entry_set_text (GTK_ENTRY (
+                        gtk_builder_get_object (builder,
+                                                "edit_dialog_ptr_entry")),
                       n_value);
 }
 
@@ -73,14 +71,12 @@ ptr_load (void *cls,
  * @return record value as a string, as specified in the dialog
  */
 static gchar *
-ptr_store (void *cls,
-         GtkBuilder *builder)
+ptr_store (void *cls, GtkBuilder *builder)
 {
   GtkEntry *entry;
   const gchar *value;
 
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_ptr_entry"));
+  entry = GTK_ENTRY (gtk_builder_get_object (builder, "edit_dialog_ptr_entry"));
   value = gtk_entry_get_text (entry);
   return g_strdup (value);
 }
@@ -98,17 +94,15 @@ ptr_store (void *cls,
  * @return #GNUNET_OK if there is a valid record value in the dialog
  */
 static int
-ptr_validate (void *cls,
-            GtkBuilder *builder)
+ptr_validate (void *cls, GtkBuilder *builder)
 {
   GtkEditable *entry;
   const gchar *preedit;
 
-  entry = GTK_EDITABLE (gtk_builder_get_object (builder,
-						"edit_dialog_ptr_entry")),
+  entry =
+    GTK_EDITABLE (gtk_builder_get_object (builder, "edit_dialog_ptr_entry")),
   preedit = gtk_editable_get_chars (entry, 0, -1);
-  if ( (NULL == preedit) ||
-       (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)) )
+  if ((NULL == preedit) || (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)))
     return GNUNET_SYSERR;
   return GNUNET_OK;
 }
@@ -125,11 +119,10 @@ libgnunet_plugin_gtk_namestore_ptr_init (void *cls)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
-  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] = {
-    { "GNS_edit_dialog_ptr_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_ptr_entry_changed_cb) },
-    { NULL, NULL }
-  };
+  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
+    {{"GNS_edit_dialog_ptr_entry_changed_cb",
+      G_CALLBACK (GNS_edit_dialog_ptr_entry_changed_cb)},
+     {NULL, NULL}};
 
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
   plugin->cls = env;
