@@ -35,8 +35,7 @@
  * @param user_data the plugin environment
  */
 static void
-GNS_edit_dialog_txt_entry_changed_cb (GtkEditable *entry,
-                                      gpointer user_data)
+GNS_edit_dialog_txt_entry_changed_cb (GtkEditable *entry, gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -54,12 +53,11 @@ GNS_edit_dialog_txt_entry_changed_cb (GtkEditable *entry,
  * @param builder the edit dialog's builder
  */
 static void
-txt_load (void *cls,
-        gchar *n_value,
-        GtkBuilder *builder)
+txt_load (void *cls, gchar *n_value, GtkBuilder *builder)
 {
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_txt_entry")),
+  gtk_entry_set_text (GTK_ENTRY (
+                        gtk_builder_get_object (builder,
+                                                "edit_dialog_txt_entry")),
                       n_value);
 }
 
@@ -73,14 +71,12 @@ txt_load (void *cls,
  * @return record value as a string, as specified in the dialog
  */
 static gchar *
-txt_store (void *cls,
-           GtkBuilder *builder)
+txt_store (void *cls, GtkBuilder *builder)
 {
   GtkEntry *entry;
   const gchar *value;
 
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_txt_entry"));
+  entry = GTK_ENTRY (gtk_builder_get_object (builder, "edit_dialog_txt_entry"));
   value = gtk_entry_get_text (entry);
   return g_strdup (value);
 }
@@ -98,8 +94,7 @@ txt_store (void *cls,
  * @return #GNUNET_OK if there is a valid record value in the dialog
  */
 static int
-txt_validate (void *cls,
-              GtkBuilder *builder)
+txt_validate (void *cls, GtkBuilder *builder)
 {
   return GNUNET_OK;
 }
@@ -116,11 +111,10 @@ libgnunet_plugin_gtk_namestore_txt_init (void *cls)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
-  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] = {
-    { "GNS_edit_dialog_txt_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_txt_entry_changed_cb) },
-    { NULL, NULL }
-  };
+  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
+    {{"GNS_edit_dialog_txt_entry_changed_cb",
+      G_CALLBACK (GNS_edit_dialog_txt_entry_changed_cb)},
+     {NULL, NULL}};
 
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
   plugin->cls = env;
