@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2012 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2012 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -41,8 +41,7 @@
  * @param result GNUNET_YES if the hostlist daemon has an integrated hostlist
  *               server, GNUNET_NO otherwise
  */
-typedef void (*TestHostlistDaemonCallback) (void *cls,
-                                            int result);
+typedef void (*TestHostlistDaemonCallback) (void *cls, int result);
 
 
 /**
@@ -69,15 +68,13 @@ struct CommandContext
    * GNUNET_YES if the target argument was found, GNUNET_NO otherwise.
    */
   int found;
-
 };
 
 
 static void
-set_checkbutton_status (void *cls,
-                        int result)
+set_checkbutton_status (void *cls, int result)
 {
-  GtkWidget * widget = cls;
+  GtkWidget *widget = cls;
   GtkToggleButton *button;
 
   if (GNUNET_YES != result)
@@ -97,10 +94,9 @@ set_checkbutton_status (void *cls,
 
 
 static void
-set_spinbutton_status (void *cls,
-                       int result)
+set_spinbutton_status (void *cls, int result)
 {
-  GtkWidget * widget = cls;
+  GtkWidget *widget = cls;
 
   if (GNUNET_YES != result)
     gtk_widget_set_sensitive (widget, FALSE);
@@ -152,13 +148,12 @@ process_hostlist_daemon_output (void *cls, const char *line)
  * @param cls closure for the callback
  */
 static void
-test_hostlist_daemon (TestHostlistDaemonCallback callback,
-                      void *cls)
+test_hostlist_daemon (TestHostlistDaemonCallback callback, void *cls)
 {
   struct CommandContext *ctx;
   char *binary;
 
-  ctx = GNUNET_malloc (sizeof (struct CommandContext));
+  ctx = GNUNET_new (struct CommandContext);
   ctx->callback = callback;
   ctx->callback_cls = cls;
   ctx->found = GNUNET_NO;
@@ -174,15 +169,15 @@ test_hostlist_daemon (TestHostlistDaemonCallback callback,
   if (NULL == ctx->cmd)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                _("Could not determine whether the hostlist daemon has"
-                  " an integrated hostlist server!\n"));
+                _ ("Could not determine whether the hostlist daemon has"
+                   " an integrated hostlist server!\n"));
     GNUNET_free (ctx);
   }
 }
 
 
 void
-GNUNET_setup_hostlist_offer_hostlist_checkbutton_realize_cb (GtkWidget * widget,
+GNUNET_setup_hostlist_offer_hostlist_checkbutton_realize_cb (GtkWidget *widget,
                                                              gpointer user_data)
 {
   test_hostlist_daemon (&set_checkbutton_status, widget);
@@ -190,7 +185,7 @@ GNUNET_setup_hostlist_offer_hostlist_checkbutton_realize_cb (GtkWidget * widget,
 
 
 void
-GNUNET_setup_hostlist_advertise_checkbutton_realize_cb (GtkWidget * widget,
+GNUNET_setup_hostlist_advertise_checkbutton_realize_cb (GtkWidget *widget,
                                                         gpointer user_data)
 {
   test_hostlist_daemon (&set_checkbutton_status, widget);
@@ -198,7 +193,7 @@ GNUNET_setup_hostlist_advertise_checkbutton_realize_cb (GtkWidget * widget,
 
 
 void
-GNUNET_setup_hostlist_server_port_spin_button_realize_cb (GtkWidget * widget,
+GNUNET_setup_hostlist_server_port_spin_button_realize_cb (GtkWidget *widget,
                                                           gpointer user_data)
 {
   test_hostlist_daemon (&set_spinbutton_status, widget);
