@@ -598,7 +598,7 @@ validate_v4_policy (const void *cls, GObject *widget)
     }
     gtk_widget_set_tooltip_text (GTK_WIDGET (widget), "");
   }
-  GNUNET_free_non_null (r);
+  GNUNET_free (r);
 }
 
 
@@ -656,7 +656,7 @@ validate_v6_policy (const void *cls, GObject *widget)
     }
     gtk_widget_set_tooltip_text (GTK_WIDGET (widget), "");
   }
-  GNUNET_free_non_null (r);
+  GNUNET_free (r);
 }
 
 
