@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -34,7 +34,7 @@
  * @param name name of the plugin to check
  */
 static void
-test_plugin (GtkWidget * widget, const char *name)
+test_plugin (GtkWidget *widget, const char *name)
 {
   if (GNUNET_YES == GNUNET_PLUGIN_test (name))
   {
@@ -48,9 +48,8 @@ test_plugin (GtkWidget * widget, const char *name)
 }
 
 
-
 void
-GNUNET_setup_transport_tcp_checkbutton_realize_cb (GtkWidget * widget,
+GNUNET_setup_transport_tcp_checkbutton_realize_cb (GtkWidget *widget,
                                                    gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_tcp");
@@ -58,7 +57,7 @@ GNUNET_setup_transport_tcp_checkbutton_realize_cb (GtkWidget * widget,
 
 
 void
-GNUNET_setup_transport_udp_checkbutton_realize_cb (GtkWidget * widget,
+GNUNET_setup_transport_udp_checkbutton_realize_cb (GtkWidget *widget,
                                                    gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_udp");
@@ -66,39 +65,39 @@ GNUNET_setup_transport_udp_checkbutton_realize_cb (GtkWidget * widget,
 
 
 void
-GNUNET_setup_transport_http_server_checkbutton_realize_cb (GtkWidget * widget,
-							   gpointer user_data)
+GNUNET_setup_transport_http_server_checkbutton_realize_cb (GtkWidget *widget,
+                                                           gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_http_server");
 }
 
 
 void
-GNUNET_setup_transport_http_client_checkbutton_realize_cb (GtkWidget * widget,
-							   gpointer user_data)
+GNUNET_setup_transport_http_client_checkbutton_realize_cb (GtkWidget *widget,
+                                                           gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_http_client");
 }
 
 
 void
-GNUNET_setup_transport_https_server_checkbutton_realize_cb (GtkWidget * widget,
-							    gpointer user_data)
+GNUNET_setup_transport_https_server_checkbutton_realize_cb (GtkWidget *widget,
+                                                            gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_https_server");
 }
 
 
 void
-GNUNET_setup_transport_https_client_checkbutton_realize_cb (GtkWidget * widget,
-							    gpointer user_data)
+GNUNET_setup_transport_https_client_checkbutton_realize_cb (GtkWidget *widget,
+                                                            gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_https_client");
 }
 
 
 void
-GNUNET_setup_transport_dv_checkbutton_realize_cb (GtkWidget * widget,
+GNUNET_setup_transport_dv_checkbutton_realize_cb (GtkWidget *widget,
                                                   gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_dv");
@@ -106,7 +105,7 @@ GNUNET_setup_transport_dv_checkbutton_realize_cb (GtkWidget * widget,
 
 
 void
-GNUNET_setup_transport_wlan_checkbutton_realize_cb (GtkWidget * widget,
+GNUNET_setup_transport_wlan_checkbutton_realize_cb (GtkWidget *widget,
                                                     gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_transport_wlan");
