@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010, 2011 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010, 2011 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -24,8 +24,6 @@
  * @author Christian Grothoff
  */
 #include "gnunet-setup.h"
-#include <gnunet/gnunet_resolver_service.h>
-#include <gnunet/gnunet_nat_lib.h>
 #include "gnunet-setup-transport-test.h"
 
 
@@ -36,11 +34,10 @@
 void
 GNUNET_setup_transport_udp_test_button_clicked_cb ()
 {
-
-  GNUNET_setup_transport_test ("transport-udp", GNUNET_NO,
+  GNUNET_setup_transport_test ("transport-udp",
+                               IPPROTO_UDP,
                                "GNUNET_setup_transport_udp_test_success_image",
                                "GNUNET_setup_transport_udp_test_fail_image");
-
 }
 
 
