@@ -231,7 +231,7 @@ widget_state_change_callback (const struct GNUNET_SETUP_OptionSpecification *os)
   else
     return;
   update_visibility (os, value);
-  GNUNET_free_non_null (value);
+  GNUNET_free (value);
 }
 
 
