@@ -57,50 +57,55 @@ struct PlotInfo
    * Name of color to use when plotting.
    */
   const char *color_name;
-
 };
 
 
 /**
  * Selected statistics for the connection tab.
  */
-static const struct PlotInfo connection_data[] = {
-  {"fs", "# peers connected", "file-sharing connections", "blue"},
-  {"core", "# peers connected", "encrypted connections (core)", "green"},
-  {"core", "# neighbour entries allocated", "transport connections (core)",
-   "yellow"},
-  {"transport", "# peers connected", "total connections (transport)", "orange"},
-  {"transport", "# TCP sessions active", "tcp connections", "red"},
-  {"transport", "# UDP sessions active", "udp connections", "gray"},
-  {"dht", "# peers connected", "DHT connections", "brown"},
-  {"nse", "# nodes in the network (estimate)", "network size (estimate)",
-   "purple"},
-  {NULL, NULL, NULL}
-};
+static const struct PlotInfo connection_data[] =
+  {{"fs", "# peers connected", "file-sharing connections", "blue"},
+   {"core", "# peers connected", "encrypted connections (core)", "green"},
+   {"core",
+    "# neighbour entries allocated",
+    "transport connections (core)",
+    "yellow"},
+   {"transport",
+    "# peers connected",
+    "total connections (transport)",
+    "orange"},
+   {"transport", "# TCP sessions active", "tcp connections", "red"},
+   {"transport", "# UDP sessions active", "udp connections", "gray"},
+   {"dht", "# peers connected", "DHT connections", "brown"},
+   {"nse",
+    "# nodes in the network (estimate)",
+    "network size (estimate)",
+    "purple"},
+   {NULL, NULL, NULL}};
 
 
 /**
  * Selected statistics for the traffic tab.
  */
-static const struct PlotInfo traffic_data[] = {
-  {"core", "# bytes encrypted", "bytes encrypted", "blue"},
-  {"core", "# bytes decrypted", "bytes decrypted", "green"},
-  {"transport", "# bytes received via TCP", "received via tcp", "yellow"},
-  {"transport", "# bytes transmitted via TCP", "sent via tcp", "brown"},
-  {NULL, NULL, NULL}
-};
+static const struct PlotInfo traffic_data[] =
+  {{"core", "# bytes encrypted", "bytes encrypted", "blue"},
+   {"core", "# bytes decrypted", "bytes decrypted", "green"},
+   {"transport", "# bytes received via TCP", "received via tcp", "yellow"},
+   {"transport", "# bytes transmitted via TCP", "sent via tcp", "brown"},
+   {NULL, NULL, NULL}};
 
 
 /**
  * Selected statistics for the storage tab.
  */
-static const struct PlotInfo storage_data[] = {
-  {"datastore", "# quota", "datastore capacity", "blue"},
-  {"datastore", "# utilization by current datastore", "datastore utilization",
-   "yellow"},
-  {"datastore", "# cache size", "reservation for datastore cache", "green"},
-  {NULL, NULL, NULL}
-};
+static const struct PlotInfo storage_data[] =
+  {{"datastore", "# quota", "datastore capacity", "blue"},
+   {"datastore",
+    "# utilization by current datastore",
+    "datastore utilization",
+    "yellow"},
+   {"datastore", "# cache size", "reservation for datastore cache", "green"},
+   {NULL, NULL, NULL}};
 
 
 /**
@@ -139,14 +144,12 @@ process_value_update (void *cls,
   GtkStatistics *stats = cls;
   char *id;
 
-  GNUNET_asprintf (&id,
-                   "%s: %s",
-                   subsystem,
-                   name);
+  GNUNET_asprintf (&id, "%s: %s", subsystem, name);
   gtk_statistics_update_value (stats,
                                id,
-                               GNUNET_TIME_absolute_get_duration
-                               (start_time).rel_value_us / 1000000LL,
+                               GNUNET_TIME_absolute_get_duration (start_time)
+                                   .rel_value_us /
+                                 1000000LL,
                                value);
   GNUNET_free (id);
   return GNUNET_OK;
@@ -173,8 +176,7 @@ get_object (const char *name)
  * @param info what to draw
  */
 static void
-create_plot (const char *box_name,
-             const struct PlotInfo *info)
+create_plot (const char *box_name, const struct PlotInfo *info)
 {
   GtkBox *box;
   GtkStatistics *ret;
@@ -185,14 +187,8 @@ create_plot (const char *box_name,
 
   for (unsigned int i = 0; NULL != info[i].subsystem; i++)
   {
-    GNUNET_asprintf (&id,
-                     "%s: %s",
-                     info[i].subsystem,
-                     info[i].name);
-    gtk_statistics_add_line (ret,
-                             id,
-                             info[i].label,
-                             info[i].color_name);
+    GNUNET_asprintf (&id, "%s: %s", info[i].subsystem, info[i].name);
+    gtk_statistics_add_line (ret, id, info[i].label, info[i].color_name);
     GNUNET_free (id);
     GNUNET_STATISTICS_watch (statistics,
                              info[i].subsystem,
@@ -201,11 +197,7 @@ create_plot (const char *box_name,
                              ret);
   }
   gtk_widget_show (GTK_WIDGET (ret));
-  gtk_box_pack_start (box,
-                      GTK_WIDGET (ret),
-                      TRUE,
-                      TRUE,
-                      0);
+  gtk_box_pack_start (box, GTK_WIDGET (ret), TRUE, TRUE, 0);
 }
 
 
@@ -219,8 +211,7 @@ shutdown_task (void *cls)
 {
   GNUNET_GTK_main_loop_quit (ml);
   ml = NULL;
-  GNUNET_STATISTICS_destroy (statistics,
-                             GNUNET_NO);
+  GNUNET_STATISTICS_destroy (statistics, GNUNET_NO);
   statistics = NULL;
 }
 
@@ -229,8 +220,7 @@ shutdown_task (void *cls)
  * Callback invoked if the application is supposed to exit.
  */
 void
-GNUNET_STATISTICS_GTK_quit_cb (GObject *object,
-                               gpointer user_data)
+GNUNET_STATISTICS_GTK_quit_cb (GObject *object, gpointer user_data)
 {
   GNUNET_SCHEDULER_shutdown ();
 }
@@ -247,20 +237,18 @@ run (void *cls)
 
   ml = cls;
 
-  if (GNUNET_OK !=
-      GNUNET_GTK_main_loop_build_window (ml,
-                                         NULL))
+  if (GNUNET_OK != GNUNET_GTK_main_loop_build_window (ml, NULL))
   {
     return;
   }
 
-  statistics
-    = GNUNET_STATISTICS_create ("gnunet-statistics-gtk",
-                                GNUNET_GTK_main_loop_get_configuration (ml));
+  statistics =
+    GNUNET_STATISTICS_create ("gnunet-statistics-gtk",
+                              GNUNET_GTK_main_loop_get_configuration (ml));
   if (NULL == statistics)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Failed to initiate connection with statistics service\n"));
+                _ ("Failed to initiate connection with statistics service\n"));
     return;
   }
   GNUNET_GTK_set_icon_search_path ();
@@ -268,31 +256,24 @@ run (void *cls)
 
   /* setup main window */
   main_window = GTK_WIDGET (get_object ("GNUNET_STATISTICS_GTK_main_window"));
-  main_window = GNUNET_GTK_plug_me ("GNUNET_STATISTICS_GTK_PLUG",
-                                    main_window);
+  main_window = GNUNET_GTK_plug_me ("GNUNET_STATISTICS_GTK_PLUG", main_window);
   gtk_window_maximize (GTK_WINDOW (main_window));
-  create_plot ("GNUNET_STATISTICS_GTK_connectivity_box",
-               connection_data);
-  create_plot ("GNUNET_STATISTICS_GTK_traffic_box",
-               traffic_data);
-  create_plot ("GNUNET_STATISTICS_GTK_storage_box",
-               storage_data);
+  create_plot ("GNUNET_STATISTICS_GTK_connectivity_box", connection_data);
+  create_plot ("GNUNET_STATISTICS_GTK_traffic_box", traffic_data);
+  create_plot ("GNUNET_STATISTICS_GTK_storage_box", storage_data);
 
   /* make GUI visible */
   gtk_widget_show (main_window);
   gtk_window_present (GTK_WINDOW (main_window));
-  GNUNET_SCHEDULER_add_shutdown (&shutdown_task,
-                                 NULL);
+  GNUNET_SCHEDULER_add_shutdown (&shutdown_task, NULL);
 }
 
 
 int
-main (int argc,
-      char *const *argv)
+main (int argc, char *const *argv)
 {
   static struct GNUNET_GETOPT_CommandLineOption options[] = {
-    GNUNET_GETOPT_OPTION_END
-  };
+    GNUNET_GETOPT_OPTION_END};
 
   start_time = GNUNET_TIME_absolute_get ();
   if (GNUNET_OK !=
