@@ -59,7 +59,6 @@ struct HistoricValue
    * A value we recorded.
    */
   uint64_t y;
-
 };
 
 /**
@@ -116,20 +115,22 @@ struct _GtkStatisticsPrivate
 
 
 static gboolean
-gtk_statistics_draw (GtkWidget * widget, cairo_t * cr);
+gtk_statistics_draw (GtkWidget *widget, cairo_t *cr);
 
 static void
-gtk_statistics_finalize (GObject * object);
+gtk_statistics_finalize (GObject *object);
 
 
-G_DEFINE_TYPE_EXTENDED (GtkStatistics, gtk_statistics, GTK_TYPE_WIDGET, 0,
+G_DEFINE_TYPE_EXTENDED (GtkStatistics,
+                        gtk_statistics,
+                        GTK_TYPE_WIDGET,
+                        0,
                         G_ADD_PRIVATE (GtkStatistics))
 
 
 #if GTK_MAJOR_VERSION < 3
 static gboolean
-statistics_expose (GtkWidget * statistics,
-                   GdkEventExpose * event)
+statistics_expose (GtkWidget *statistics, GdkEventExpose *event)
 {
   GtkAllocation alloc;
   cairo_t *cr;
@@ -137,8 +138,12 @@ statistics_expose (GtkWidget * statistics,
   gint y;
 
   gtk_widget_translate_coordinates (statistics,
-                                    GTK_WIDGET (gtk_widget_get_toplevel
-                                                (statistics)), 0, 0, &x, &y);
+                                    GTK_WIDGET (
+                                      gtk_widget_get_toplevel (statistics)),
+                                    0,
+                                    0,
+                                    &x,
+                                    &y);
   gtk_widget_get_allocation (statistics, &alloc);
   cr = gdk_cairo_create (statistics->window);
   cairo_translate (cr, x, y);
@@ -153,7 +158,7 @@ statistics_expose (GtkWidget * statistics,
 
 
 static void
-gtk_statistics_class_init (GtkStatisticsClass * class)
+gtk_statistics_class_init (GtkStatisticsClass *class)
 {
   GObjectClass *gobject_class;
   GtkWidgetClass *widget_class;
@@ -169,16 +174,18 @@ gtk_statistics_class_init (GtkStatisticsClass * class)
 
 
 static void
-gtk_statistics_init (GtkStatistics * statistics)
+gtk_statistics_init (GtkStatistics *statistics)
 {
   GtkStatisticsPrivate *priv;
 
-  statistics->priv =
-      G_TYPE_INSTANCE_GET_PRIVATE (statistics, GTK_TYPE_STATISTICS,
-                                   GtkStatisticsPrivate);
+  statistics->priv = G_TYPE_INSTANCE_GET_PRIVATE (statistics,
+                                                  GTK_TYPE_STATISTICS,
+                                                  GtkStatisticsPrivate);
   priv = statistics->priv;
 #if GTK_MAJOR_VERSION < 3
-  g_signal_connect (statistics, "expose-event", G_CALLBACK (statistics_expose),
+  g_signal_connect (statistics,
+                    "expose-event",
+                    G_CALLBACK (statistics_expose),
                     statistics);
 #endif
   gtk_widget_set_has_window (GTK_WIDGET (statistics), FALSE);
@@ -219,10 +226,10 @@ gtk_statistics_new ()
  * @param color_name name of the color to use
  */
 void
-gtk_statistics_add_line (GtkStatistics * statistics,
-			 const char *id,
+gtk_statistics_add_line (GtkStatistics *statistics,
+                         const char *id,
                          const char *label,
-			 const char *color_name)
+                         const char *color_name)
 {
   GtkStatisticsPrivate *priv;
   struct ValueHistory *vh;
@@ -232,10 +239,10 @@ gtk_statistics_add_line (GtkStatistics * statistics,
   g_return_if_fail (gdk_rgba_parse (&c, color_name));
   priv = statistics->priv;
   priv->values =
-      g_realloc (priv->values,
-                 sizeof (struct ValueHistory *) * (1 + priv->num_values));
+    g_realloc (priv->values,
+               sizeof (struct ValueHistory *) * (1 + priv->num_values));
   priv->values[priv->num_values++] = vh =
-      g_malloc (sizeof (struct ValueHistory));
+    g_malloc (sizeof (struct ValueHistory));
   vh->id = strdup (id);
   vh->label = strdup (label);
   vh->red = c.red;
@@ -255,8 +262,10 @@ gtk_statistics_add_line (GtkStatistics * statistics,
  * @param y new y-value
  */
 void
-gtk_statistics_update_value (GtkStatistics * statistics, const char *id,
-                             uint64_t x, uint64_t y)
+gtk_statistics_update_value (GtkStatistics *statistics,
+                             const char *id,
+                             uint64_t x,
+                             uint64_t y)
 {
   GtkStatisticsPrivate *priv;
   GtkWidget *widget;
@@ -313,7 +322,7 @@ num_to_label (unsigned long long num, char *label)
  * @param cr drawing context
  */
 static gboolean
-gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
+gtk_statistics_draw (GtkWidget *widget, cairo_t *cr)
 {
   GtkStatistics *statistics = GTK_STATISTICS (widget);
   GtkStatisticsPrivate *priv = statistics->priv;
@@ -344,8 +353,8 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
     vh = priv->values[i];
     for (j = 0; j < vh->history_size; j++)
     {
-      hv = &vh->history[(vh->last_history_offset - j + MAX_HISTORY) %
-                        MAX_HISTORY];
+      hv =
+        &vh->history[(vh->last_history_offset - j + MAX_HISTORY) % MAX_HISTORY];
       xmin = GNUNET_MIN (hv->x, xmin);
       xmax = GNUNET_MAX (hv->x, xmax);
       ymax = GNUNET_MAX (hv->y, ymax);
@@ -368,10 +377,12 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
   cairo_paint (cr);
 
   if ((0 == priv->num_values) || (ymax == 0))
-    return FALSE;               /* done */
+    return FALSE; /* done */
   /* select font */
   cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
-  cairo_select_font_face (cr, "Georgia", CAIRO_FONT_SLANT_NORMAL,
+  cairo_select_font_face (cr,
+                          "Georgia",
+                          CAIRO_FONT_SLANT_NORMAL,
                           CAIRO_FONT_WEIGHT_BOLD);
   cairo_set_font_size (cr, GNUNET_MIN (20, height / (2 * XTICKS)));
 
@@ -380,9 +391,8 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
   tex_max.height = 0;
   for (i = 0; i < XTICKS; i++)
   {
-    num_to_label ((unsigned long long) (xmin +
-                                        (xmax -
-                                         xmin) * ((uint64_t) i) / (XTICKS - 1)),
+    num_to_label ((unsigned long long) (xmin + (xmax - xmin) * ((uint64_t) i) /
+                                                 (XTICKS - 1)),
                   label);
     cairo_text_extents (cr, label, &te);
     tex_max.width = GNUNET_MAX (te.width, tex_max.width);
@@ -405,32 +415,30 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
     num_to_label ((unsigned long long) ymax * ((uint64_t) i) / (YTICKS - 1),
                   label);
     cairo_text_extents (cr, label, &te);
-    cairo_move_to (cr, BORDER + tey_max.width - te.width,
-                   BORDER + tey_max.height + (YTICKS - i - 1) * (height -
-                                                                 2.0 * BORDER -
-                                                                 tey_max.height
-                                                                 -
-                                                                 tex_max.height)
-                   / (double) (YTICKS - 1));
+    cairo_move_to (cr,
+                   BORDER + tey_max.width - te.width,
+                   BORDER + tey_max.height +
+                     (YTICKS - i - 1) *
+                       (height - 2.0 * BORDER - tey_max.height -
+                        tex_max.height) /
+                       (double) (YTICKS - 1));
     cairo_show_text (cr, label);
 
 
-    cairo_move_to (cr, 2.0 * BORDER + tey_max.width,
-                   BORDER + tey_max.height / 2.0 + (YTICKS - i - 1) * (height -
-                                                                       2.0 *
-                                                                       BORDER -
-                                                                       tex_max.height
-                                                                       -
-                                                                       tey_max.height)
-                   / (double) (YTICKS - 1));
-    cairo_line_to (cr, 2.0 * BORDER + tey_max.width + BORDER / 2.0,
-                   BORDER + tey_max.height / 2.0 + (YTICKS - i - 1) * (height -
-                                                                       2.0 *
-                                                                       BORDER -
-                                                                       tex_max.height
-                                                                       -
-                                                                       tey_max.height)
-                   / (double) (YTICKS - 1));
+    cairo_move_to (cr,
+                   2.0 * BORDER + tey_max.width,
+                   BORDER + tey_max.height / 2.0 +
+                     (YTICKS - i - 1) *
+                       (height - 2.0 * BORDER - tex_max.height -
+                        tey_max.height) /
+                       (double) (YTICKS - 1));
+    cairo_line_to (cr,
+                   2.0 * BORDER + tey_max.width + BORDER / 2.0,
+                   BORDER + tey_max.height / 2.0 +
+                     (YTICKS - i - 1) *
+                       (height - 2.0 * BORDER - tex_max.height -
+                        tey_max.height) /
+                       (double) (YTICKS - 1));
 
     cairo_stroke (cr);
   }
@@ -438,41 +446,42 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
   /* draw x-axis labels */
   for (i = 0; i < XTICKS; i++)
   {
-    num_to_label ((unsigned long long) (xmin +
-                                        (xmax -
-                                         xmin) * ((uint64_t) i) / (XTICKS - 1)),
+    num_to_label ((unsigned long long) (xmin + (xmax - xmin) * ((uint64_t) i) /
+                                                 (XTICKS - 1)),
                   label);
     cairo_text_extents (cr, label, &te);
     if (i != 0)
     {
       cairo_move_to (cr,
-                     2.0 * BORDER + tey_max.width + (width - tey_max.width -
-                                                     tex_max.width / 2.0 -
-                                                     3.0 * BORDER) * i /
-                     (XTICKS - 1.0) - te.width / 2.0,
+                     2.0 * BORDER + tey_max.width +
+                       (width - tey_max.width - tex_max.width / 2.0 -
+                        3.0 * BORDER) *
+                         i / (XTICKS - 1.0) -
+                       te.width / 2.0,
                      height - BORDER / 2.0 - tex_max.height / 2.0);
       cairo_show_text (cr, label);
     }
     cairo_move_to (cr,
-                   2.0 * BORDER + tey_max.width + (width - tey_max.width -
-                                                   tex_max.width / 2.0 -
-                                                   3.0 * BORDER) * i / (XTICKS -
-                                                                        1.0),
+                   2.0 * BORDER + tey_max.width +
+                     (width - tey_max.width - tex_max.width / 2.0 -
+                      3.0 * BORDER) *
+                       i / (XTICKS - 1.0),
                    height - BORDER - tey_max.height / 2.0 - tex_max.height);
     cairo_line_to (cr,
-                   2.0 * BORDER + tey_max.width + (width - tey_max.width -
-                                                   tex_max.width / 2.0 -
-                                                   3.0 * BORDER) * i / (XTICKS -
-                                                                        1.0),
+                   2.0 * BORDER + tey_max.width +
+                     (width - tey_max.width - tex_max.width / 2.0 -
+                      3.0 * BORDER) *
+                       i / (XTICKS - 1.0),
                    height - BORDER - tey_max.height / 2.0 - tex_max.height -
-                   BORDER / 2.0);
+                     BORDER / 2.0);
 
     cairo_stroke (cr);
   }
 
   /* plot border */
   cairo_set_line_width (cr, 1.0);
-  cairo_rectangle (cr, tey_max.width + BORDER * 2.0,
+  cairo_rectangle (cr,
+                   tey_max.width + BORDER * 2.0,
                    BORDER + tey_max.height / 2.0,
                    width - BORDER * 3.0 - tey_max.width - tex_max.width / 2.0,
                    height - BORDER * 2.0 - tey_max.height - tex_max.height);
@@ -484,8 +493,8 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
   cairo_set_font_size (cr,
                        GNUNET_MIN (20,
                                    (height - 3.0 * BORDER - tex_max.height -
-                                    tey_max.height / 2) / (priv->num_values +
-                                                           1)));
+                                    tey_max.height / 2) /
+                                     (priv->num_values + 1)));
 
   h = 2.0 * BORDER + tey_max.height / 2;
 
@@ -502,9 +511,9 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
     {
       hv = &vh->history[vh->last_history_offset % MAX_HISTORY];
       ry = hv->y / (double) ymax;
-      ry = BORDER + tex_max.height / 2.0 + (1.0 - ry) * (height - BORDER * 2.0 -
-                                                         tey_max.height -
-                                                         tex_max.height);
+      ry =
+        BORDER + tex_max.height / 2.0 +
+        (1.0 - ry) * (height - BORDER * 2.0 - tey_max.height - tex_max.height);
       /* if y-values are small, offset y-values a bit to allow overlapping curves to still show up */
       if (ymax < height / (priv->num_values * 4))
         ry += priv->num_values * 2 - (4 * i);
@@ -516,16 +525,16 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
 
     for (j = 0; j < vh->history_size; j++)
     {
-      hv = &vh->history[(vh->last_history_offset - j + MAX_HISTORY) %
-                        MAX_HISTORY];
+      hv =
+        &vh->history[(vh->last_history_offset - j + MAX_HISTORY) % MAX_HISTORY];
       rx = (hv->x - xmin) / (double) (xmax - xmin);
       ry = hv->y / (double) ymax;
 
       rx = tey_max.width + BORDER * 2.0 +
-          (rx * (width - BORDER * 3.0 - tey_max.width - tex_max.width / 2.0));
-      ry = BORDER + tex_max.height / 2.0 + (1.0 - ry) * (height - BORDER * 2.0 -
-                                                         tey_max.height -
-                                                         tex_max.height);
+           (rx * (width - BORDER * 3.0 - tey_max.width - tex_max.width / 2.0));
+      ry =
+        BORDER + tex_max.height / 2.0 +
+        (1.0 - ry) * (height - BORDER * 2.0 - tey_max.height - tex_max.height);
 
       /* if y-values are small, offset y-values a bit to allow overlapping curves to still show up */
       if (ymax < height / (priv->num_values * 4))
@@ -546,7 +555,7 @@ gtk_statistics_draw (GtkWidget * widget, cairo_t * cr)
  * @param object object to release
  */
 static void
-gtk_statistics_finalize (GObject * object)
+gtk_statistics_finalize (GObject *object)
 {
   GtkStatistics *label = GTK_STATISTICS (object);
   GtkStatisticsPrivate *priv = label->priv;
